Coverage for .tox/cov/lib/python3.11/site-packages/confattr/state.py: 100%

1#!/usr/bin/env python3

2

3#: This is set when instantiating a :class:`~confattr.configfile.ConfigFile` without passing :paramref:`~confattr.configfile.ConfigFile.config_instances`, i.e. one that should support all settings.

4#: Trying to create a :class:`~confattr.config.Config` when this flag is set will raise a :class:`~confattr.config.TimingError`.

5 has_config_file_been_instantiated = False